* Note: the core data for this paper comes from the EEO-1 database, which I do not have the right to share. I include the do-codes for replicating the key tables and figure. I plan to post my data on CEO donation and CEO race/gender characteristics used in this paper at some point as well. 

************************************ data construction *************************************
* define whether each establishment's HQ state has just banned AA in that year
gen hqban=0  if hq==1
replace hqban=1 if year==2006 & state_abbr=="MI" & hq==1
replace hqban=1 if year==1998 & state_abbr=="WA" & hq==1
replace hqban=1 if year==1996 & state_abbr=="CA" & hq==1
replace hqban=1 if year==1999 & state_abbr=="FL" & hq==1
replace hqban=1 if year==2008 & state_abbr=="NE" & hq==1
replace hqban=1 if year==2010 & state_abbr=="AZ" & hq==1
replace hqban=1 if year==2011 & state_abbr=="NH" & hq==1
replace hqban=1 if year==2012 & state_abbr=="OK" & hq==1
replace hqban=1 if year==1996 & state_abbr=="TX" & hq==1
gsort hdq_nbr year -hq
by hdq_nbr year: replace hqban=hqban[1]


************************************** matching  **********************************
*the basic strategy is to match based on sic3 fips firmt10_group (firm size quartile). I tried to find two controls per each treated establishment. For those treat establishments that cannot be matched to two control establishments, I matched them to only one control. I excluded treat establishments that cannot be matched to any control establishment. 

sort unit_nbr year
gen hqban2=0 //hqban2 measures how many years before/after the ban
foreach x of num 1/20{
by unit_nbr: replace hqban2=`x' if hqban[_n-`x']==1
}
foreach x of num 0/20{
by unit_nbr: replace hqban2=-`x'-1 if hqban[_n+`x']==1
}

gen hqban2_pos=hqban2 if hqban2>=0  //how many years after the ban
replace hqban2_pos=0 if hqban2<0
gen hqban2_neg=-hqban2 if hqban2<=0 //how many years before the ban
replace hqban2_neg=0 if hqban2>0

gen hqban2_post=1 if hqban2>0 //a general indicator whether it is before/after the ban
replace hqban2_post=0 if hqban2<0
replace hqban2_post=0 if hqban2==0

gen u=runiform() //a random number generator
gen n=2 //one treat matched to n controls
gen year_before_ban=hqban2==-1 // a binary variable indicating 1 if it is the year before the ban and 0 otherwise. 

gsort year sic3 fips firmt10_group year_before_ban u
by year sic3 fips firmt10_group  year_before_ban: gen num_treat=_N if year_before_ban==1 //count the num of treat establishment in each sic3/fips/firmt10_group category
by year sic3 fips firmt10_group  year_before_ban: gen order_treat=_n if year_before_ban==1 //a randomized order of treat establishment in each sic3/fips/firmt10_group category, used later to exclude treatment establishment that cannot be matched to a control

gsort year sic3 fips firmt10_group -year_before_ban //put valid observation for num_treat at the top of each category
by year sic3 fips firmt10_group : replace num_treat=num_treat[1] if num_treat==. //set the number of treat establishment in each category for all observations in that category
by year sic3 fips firmt10_group : gen total_num_in_category=_N //total num of establishment in each sic3/fips/firmt10_group category

gen treatment_exclude=1 if order_treat>(total_num_in_category-num_treat) & year_before_ban==1 //in those categories where the num of treat establishment surpasses the num of control establishment, I excluded the extra treatment establishment.
gsort unit_nbr treatment_exclude
by unit_nbr: replace treatment_exclude=treatment_exclude[1] //set the exclusion criteria for excluded establishment for all years

gen nontreat_est=hqban2~=0 //all establishments that have never been treated (no affirmative action ban at their HQ states)
gsort year sic3 fips firmt10_group nontreat_est u

replace num_treat=num_treat*n //we want match 2 control establishments per treatment, so n==2 in this case. we use num_treat to indicate how many control establishments to take per category
by year sic3 fips firmt10_group nontreat_est: gen phqban2=-1 if hqban2==0 & _n<=num_treat & num_treat~=. // phqban2 is the num of years before and after the ban for the control group
gsort unit_nbr year
foreach x of num 1/20 {
by unit_nbr: replace phqban2=`x' if phqban2[_n-`x']==-1
}
foreach x of num 0/20 {
by unit_nbr: replace phqban2=-`x'-1 if phqban2[_n+`x']==-1
}
replace phqban2=0 if phqban2==.

gen phqban2_pos=0 //phqban2_pos is the same as hqban2_pos except that it is for the control establishments
gen phqban2_neg=0
replace phqban2_pos=phqban2 if phqban2>0
replace phqban2_neg=-phqban2 if phqban2<0

*combine hqban2 and phqban2 into tqban2
gen thqban2=hqban2
replace thqban2=phqban2 if thqban2==.

gen thqban2_post=1 if (hqban2_pos>0 & hqban2_pos~=.) | (phqban2_pos>0 & phqban2_pos~=.)
replace thqban2_post=0 if (hqban2_neg>0 & hqban2_neg~=.) | (phqban2_neg>0 & phqban2_neg~=.)

gen sample=0 if phqban2~=0 // sample==0 for control establishments and sample==1 for treat establishments
replace sample=1 if hqban2~=0

gen thqban2_post_sample=thqban2_post*sample

* Notes on variables
// unit of analysis is establishment-year; establishment ID is unit_nbr and firm ID is hdq_nbr
// blkt1pct_00 is the number of Black managers over the total number of managers in an establishment, multiplied by 100.
// blkt2pct is the number of Black professionals over the total number of professionals in an establishment. 
// blkt10_1pct is the number of Black non-managerial employees over the total number of non-managerial employees in an establishment. 
// wh refers to White employees, asian to Asian employees, hisp to Hispanic employees, and f refers to women employees
// pctmanagers is the number of managers over the total number of employees in an establishment
// pctmanagers is the number of managers over the total number of employees in an establishment
// pctprof is the number of professionals over the total number of employees in an establishment
// pctbackoffice is the number of backoffice employees over the total number of employees in an establishment
// pctbluecollar is the number of bluecollar employees over the total number of employees in an establishment
// logt10 is the logged number of total employees in an establishment
// lognum_est is the logged number of total establishments for the firmt10_group
// thqban2_post_sample is the interaction between HQ post-ban and treat; this is the variable of interest
// sampling criteria: we excluded those treat establishments that cannot be matched to a control !(treatment_exclude~=1), those located in counties with few Black residents !(pct_labor_force_b>0.03), establishments outside of both the treat group and the control group !(phqban2~=0 | hqban2~=0), and establishments outside of the 20-year window of observation !(thqban2<11 & thqban2>-11).
// due to the use of the random number generator in matching, results from each iteration of the sample construction will be slightly different.

********************************* Main Table **************************************
eststo clear
areg blkt1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03 &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e1
areg blkm1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03 &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e2
areg blkf1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03 &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e3
areg wht1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03  &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e4
areg whm1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03  &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e5
areg whf1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03  &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e6
areg asiant1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03  &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e7
areg hispt1pct_00 thqban2_post_sample blkt2pct wht2pct hispt2pct asiant2pct ft2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if treatment_exclude~=1 & pct_labor_force_b>0.03  &  thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e8

estadd local yfixed "Yes", replace: e1 e2 e3 e4 e5 e6 e7 e8
estadd local ffixed "Yes", replace: e1 e2 e3 e4 e5 e6 e7 e8
estadd local lafixed "Yes", replace: e1 e2 e3 e4 e5 e6 e7 e8
estadd local wofixed "Yes", replace: e1 e2 e3 e4 e5 e6 e7 e8

esttab e1 e2 e3 e4 e5 e6 e7 e8 using maintable1.tex, replace label se r2 wrap width(\hsize) ///
title("\label{tab:maintable1} Linear Estimation with Matching (Main Models): Predicting Managerial Composition") ///
mgroups("Pct Black" "Pct White" "Pct Asian" "Pct Hispanic" "Pct Women", pattern(1 0 0 1 0 0 1 1) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
mtitles("All" "Men" "Women" "All" "Men" "Women" "All" "All" ) ///
noomitted keep(thqban2_post_sample pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat thqban2_post sample) ///
order(thqban2_post_sample pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor hq_govparty_democrat hq_leg_democrat thqban2_post sample) ///
scalar("yfixed Year Fixed Effects" "ffixed Estab. Fixed Effects" "lafixed Local Demographics" "wofixed Workers' Demographics")


// analyses with CEO information run on a subsample (merge between EEO and Compustat)
// I excluded firms that experienced a change in CEO during the study period (changedceorep~=1)
// dem_amt_by_total is the proportion of CEO donation given to the Democratic party candidates. This is coded from the FEC's political donation database
gen thqban2_post_sample_dt=thqban2_post*sample*dem_amt_by_total
gen thqban2_post_dt=thqban2_post*dem_amt_by_total
gen sample_dt=sample*dem_amt_by_total
****************************** Table with Moderators: Democrats vs. Republican CEOs ***********************************
eststo clear
areg blkt1pct_00 thqban2_post_sample thqban2_post_sample_dt blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample thqban2_post_dt sample_dt if changedceorep~=1 & pct_labor_force_b>0.03 & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e1
areg blkt1pct_00 thqban2_post_sample thqban2_post_sample_dt blkt10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample  thqban2_post_dt sample_dt if changedceorep~=1 & pct_labor_force_b>0.03 & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e2
areg blkt1pct_00 thqban2_post_sample blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if changedceorep~=1 & dem_amt_by_total<0.5 & pct_labor_force_b>0.03 & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e3
areg blkt1pct_00 thqban2_post_sample pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if changedceorep~=1 & dem_amt_by_total<0.5 & pct_labor_force_b>0.03 & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e4
areg blkt1pct_00 thqban2_post_sample blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if changedceorep~=1 & dem_amt_by_total>0.5 & dem_amt_by_total~=. &  pct_labor_force_b>0.03 & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e5
areg blkt1pct_00 thqban2_post_sample pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat i.year thqban2_post sample if changedceorep~=1 &  dem_amt_by_total>0.5 & dem_amt_by_total~=. & pct_labor_force_b>0.03 & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
est store e6

estadd local yfixed "Yes", replace: e1 e2 e3 e4 e5 e6
estadd local ffixed "Yes", replace: e1 e2 e3 e4 e5 e6
estadd local lafixed "Yes", replace: e1 e2 e3 e4 e5 e6
estadd local wofixed "Yes", replace: e1 e3 e5
estadd local oofixed "Yes", replace: e1 e2 e3 e4 e5 e6

esttab e1 e2 e3 e4 e5 e6 using maintable3.tex, replace label se r2 wrap width(\hsize) ///
title("\label{tab:maintable3} Conservative versus Liberal CEOs: Predicting Proportion of Black Managers") ///
mgroups("Full Sample" "Conservative CEOs" "Liberal CEOs", pattern(1 0 1 0 1 0) prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
nomtitles ///
noomitted keep(thqban2_post_sample thqban2_post_sample_dt logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat thqban2_post thqban2_post_dt sample_dt) ///
order(thqban2_post_sample thqban2_post_sample_dt thqban2_post_sample_dt logt10 lognum_est federal_contractor roa3 logtobinq3 ceo_age2 ceo_women2 ceo_minority2 hq_govparty_democrat hq_leg_democrat thqban2_post thqban2_post_dt sample_dt) ///
scalar("yfixed Year Fixed Effects" "ffixed Establishment Fixed Effects" "lafixed Local Demographics" "wofixed Workers' Demographics" "oofixed Occupational Composition")

****************************** Constructing the Main Graph ***********************************
foreach x of numlist 1/10 {
gen thqban2_pos`x'=0
replace thqban2_pos`x'=1 if thqban2==`x'
}
foreach x of numlist 1/10 {
gen thqban2_neg`x'=0
replace thqban2_neg`x'=1 if thqban2==-`x'
}
foreach x of numlist 1/10 {
gen thqban2_pos`x'_sample=thqban2_pos`x'*sample
la var thqban2_pos`x'_sample "`x' Years after Ban x Target"
}
foreach x of numlist 1/10 {
gen thqban2_neg`x'_sample=thqban2_neg`x'*sample
la var thqban2_neg`x'_sample "`x' Years before Ban x Target"
} //constructing new variables for the graph. 

//estimated difference between treatment and control establishments (in the proportion of Black managers)
areg blkt1pct_00 blkt2pct wht2pct hispt2pct asiant2pct blkt10_1pct wht10_1pct hispt10_1pct asiant10_1pct ft10_1pct pct_labor_force_women-pct_labor_force_h pctmanagers pctprof pctbackoffice pctbluecollar logt10 lognum_est c.federal_contractor i.year thqban2_pos1_sample-thqban2_pos10_sample thqban2_neg2_sample-thqban2_neg10_sample thqban2_pos1-thqban2_pos10 thqban2_neg2-thqban2_neg10 if treatment_exclude~=1 & pct_labor_force_b>0.03 & blkt2pct~=. & thqban2<11 & thqban2>-11 & (phqban2~=0 | hqban2~=0) & year>1984, a(unit_nbrs) cluster(hdq_nbrs)
	drop tp tp_se tp_year tp_se1 tp_se2
	gen tp=.
	gen tp_se=.
	gen tp_year=.
	gen tp_se1=.
	gen tp_se2=.

	foreach x of numlist 1/10 {
	replace tp=_b[thqban2_pos`x'_sample] if _n==`x'
	replace tp_se=_se[thqban2_pos`x'_sample] if _n==`x'
	replace tp_year=`x' if _n==`x'
	}
	foreach x of numlist 2/10 {
	replace tp=_b[thqban2_neg`x'_sample] if _n==`x'+100
	replace tp_se=_se[thqban2_neg`x'_sample] if _n==`x'+100
	replace tp_year=1-`x' if _n==`x'+100
	}
	replace tp=0 if _n==15
	replace tp_year=0 if _n==15
	replace tp_se1=tp+1.645*tp_se
	replace tp_se2=tp-1.645*tp_se

	twoway (connected tp tp_year, lc(black) mc(black)  msymbol(o) sort) (rcap tp_se1 tp_se2 tp_year, lc(black) mc(black)), ///
	xlabel(-9(1)10) xline(0, lcolor(black) lpattern(dash)) yline(0, lcolor(black) lpattern(dash)) graphregion(color(white)) legend(off) graphregion(color(white)) ///
	xtitle("Years before/after Affirmative Action Ban") ytitle("Percentage Points")


****************************** Simple Codes in Constructing the EEO-1 Variables ***********************************
gen blkt1pct_00=blkt1/t1*100
gen wht1pct_00=wht1/t1*100
gen asiant1pct_00=asiant1/t1*100
gen hispt1pct_00=hispt1/t1*100

gen blkt10_1pct=(blkt10-blkt1)/(t10-t1)
gen wht10_1pct=(wht10-wht1)/(t10-t1)
gen asiant10_1pct=(asiant10-asiant1)/(t10-t1)
gen hispt10_1pct=(hispt10-hispt1)/(t10-t1)

gen blkt2pct=blkt2/t2
gen wht2pct=wht2/t2
gen asiant2pct=asiant2/t2
gen hispt2pct=hispt2/t2




